@@ -68,11 +68,11 @@ class UserIdentity(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="userPool")
-    def user_pool(self) -> typing.Optional[aws_cdk.aws_cognito.UserPool]:
+    def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         '''
         :stability: experimental
         '''
-        return typing.cast(typing.Optional[aws_cdk.aws_cognito.UserPool], jsii.get(self, "userPool"))
+        return typing.cast(aws_cdk.aws_cognito.UserPool, jsii.get(self, "userPool"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="userPoolClient")
