@@ -16,10 +16,7 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity",
-    "0.3.13",
-    __name__[0:-6],
-    "identity@0.3.13.jsii.tgz",
+    "@aws-prototyping-sdk/identity", "0.4.0", __name__[0:-6], "identity@0.4.0.jsii.tgz"
 )
 
 __all__ = [
